@@ -148,6 +148,26 @@ class PyClasslike(BaseObject, python.PyClasslike):
 
 # ----------------------------------------------------------------------------
 
+# Create multi-inheritance classes to merge BaseObject from Breathe with
+# classes from phpdomain.
+# We use capitalization (and the namespace) to differentiate between the two
+
+if php is not None:
+    class PHPNamespaceLevel(BaseObject, php.PhpNamespacelevel):
+        """Description of a PHP item *in* a namespace (not the space itself)."""
+        pass
+
+    class PHPClassLike(BaseObject, php.PhpClasslike):
+        pass
+
+    class PHPClassMember(BaseObject, php.PhpClassmember):
+        pass
+
+    class PHPGlobalLevel(BaseObject, php.PhpGloballevel):
+        pass
+
+# ----------------------------------------------------------------------------
+
 if cs is not None:
     class CSharpCurrentNamespace(BaseObject, cs.CSharpCurrentNamespace):
         pass
@@ -239,12 +259,13 @@ class DomainDirectiveFactory:
 
     if php is not None:
         php_classes = {
-            'function': (php.PhpNamespacelevel, 'function'),
-            'class': (php.PhpClasslike, 'class'),
-            'attr': (php.PhpClassmember, 'attr'),
-            'method': (php.PhpClassmember, 'method'),
-            'global': (php.PhpGloballevel, 'global'),
+            'function': (PHPNamespaceLevel, 'function'),
+            'class': (PHPClassLike, 'class'),
+            'attr': (PHPClassMember, 'attr'),
+            'method': (PHPClassMember, 'method'),
+            'global': (PHPGlobalLevel, 'global'),
         }
+        php_classes_default = php_classes['class']  # Directive when no matching ones were found
 
     if cs is not None:
         cs_classes = {
@@ -291,8 +312,12 @@ class DomainDirectiveFactory:
             else:
                 if arg_0 in ['variable']:
                     arg_0 = 'global'
-            cls, name = DomainDirectiveFactory.php_classes.get(
-                arg_0, (php.PhpClasslike, 'class'))
+
+            if arg_0 in DomainDirectiveFactory.php_classes:
+                cls, name = DomainDirectiveFactory.php_classes[arg_0]  # type: ignore
+            else:
+                cls, name = DomainDirectiveFactory.php_classes_default  # type: ignore
+
         elif cs is not None and domain == 'cs':
             cls, name = DomainDirectiveFactory.cs_classes[args[0]]  # type: ignore
         else:
@@ -1319,8 +1344,20 @@ class SphinxRenderer:
             print("Warning: does not currently handle 'small' text display")
         return [creator("", "", *nodelist)]
 
-    def visit_docsect1(self, node) -> List[Node]:
-        return []
+    def visit_docsectN(self, node) -> List[Node]:
+        '''
+        Docutils titles are defined by their level inside the document so
+        the proper structure is only guaranteed by the Doxygen XML.
+
+        Doxygen command mapping to XML element name:
+        @section == sect1, @subsection == sect2, @subsubsection == sect3
+        '''
+        section = nodes.section()
+        section['ids'].append(self.get_refid(node.id))
+        section += self.create_doxygen_target(node)
+        section += nodes.title(node.title, node.title)
+        section += self.render_iterable(node.content_)
+        return [section]
 
     def visit_docsimplesect(self, node) -> List[Node]:
         """Other Type documentation such as Warning, Note, Returns, etc"""
@@ -1585,9 +1622,39 @@ class SphinxRenderer:
         content = node.term.content_
         return self.render_iterable(content)
 
-    def visit_docanchor(self, node) -> List[None]:
+    def visit_docanchor(self, node) -> List[Node]:
         return self.create_doxygen_target(node)
 
+    def visit_docentry(self, node) -> List[Node]:
+        col = nodes.entry()
+        col += self.render_iterable(node.para)
+        if node.thead == 'yes':
+            col['heading'] = True
+        return [col]
+
+    def visit_docrow(self, node) -> List[Node]:
+        row = nodes.row()
+        cols = self.render_iterable(node.entry)
+        if all(col.get('heading', False) for col in cols):
+            elem = nodes.thead()
+        else:
+            elem = nodes.tbody()
+        row += cols
+        elem += row
+        return [elem]
+
+    def visit_doctable(self, node) -> List[Node]:
+        table = nodes.table()
+        table['classes'] += ['colwidths-auto']
+        tgroup = nodes.tgroup(cols=node.cols)
+        for _ in range(node.cols):
+            colspec = nodes.colspec()
+            colspec.attributes['colwidth'] = 'auto'
+            tgroup += colspec
+        table += tgroup
+        tgroup += self.render_iterable(node.row)
+        return [table]
+
     def visit_mixedcontainer(self, node) -> List[Node]:
         return self.render_optional(node.getValue())
 
@@ -1607,8 +1674,19 @@ class SphinxRenderer:
                 declaration = name + node.get_argsstring()
             else:
                 elements = [self.create_template_prefix(node)]
+                if node.static == 'yes':
+                    elements.append('static')
+                if node.inline == 'yes':
+                    elements.append('inline')
                 if node.kind == 'friend':
                     elements.append('friend')
+                if node.virt in ('virtual', 'pure-virtual'):
+                    elements.append('virtual')
+                if node.explicit == 'yes':
+                    elements.append('explicit')
+                if 'constexpr' in dir(node):
+                    assert node.constexpr == 'yes'
+                    elements.append('constexpr')
                 elements.append(''.join(n.astext()
                                         for n in self.render(node.get_type())))  # type: ignore
                 elements.append(name)
@@ -1758,16 +1836,19 @@ class SphinxRenderer:
             if len(initializer) != 0:
                 options['value'] = initializer
         else:
+            elements = [self.create_template_prefix(node)]
+            if node.static == 'yes':
+                elements.append('static')
+            if node.mutable == 'yes':
+                elements.append('mutable')
             typename = ''.join(n.astext() for n in self.render(node.get_type()))
             if dom == 'c' and '::' in typename:
                 typename = typename.replace('::', '.')
-            declaration = ' '.join([
-                self.create_template_prefix(node),
-                typename,
-                name,
-                node.get_argsstring(),
-                self.make_initializer(node)
-            ])
+            elements.append(typename)
+            elements.append(name)
+            elements.append(node.get_argsstring())
+            elements.append(self.make_initializer(node))
+            declaration = ' '.join(elements)
         if not dom or dom in ('c', 'cpp', 'py', 'cs'):
             return self.handle_declaration(node, declaration, options=options)
         else:
@@ -1947,7 +2028,9 @@ class SphinxRenderer:
         "docimage": visit_docimage,
         "docurllink": visit_docurllink,
         "docmarkup": visit_docmarkup,
-        "docsect1": visit_docsect1,
+        "docsect1": visit_docsectN,
+        "docsect2": visit_docsectN,
+        "docsect3": visit_docsectN,
         "docsimplesect": visit_docsimplesect,
         "doctitle": visit_doctitle,
         "docformula": visit_docformula,
@@ -1974,6 +2057,9 @@ class SphinxRenderer:
         "docvariablelist": visit_docvariablelist,
         "docvarlistentry": visit_docvarlistentry,
         "docanchor": visit_docanchor,
+        "doctable": visit_doctable,
+        "docrow": visit_docrow,
+        "docentry": visit_docentry,
     }
 
     def render(self, node, context: Optional[RenderContext] = None) -> List[Node]:
